pub struct MergedFile {
pub existing: Option<String>,
pub rendered: String,
}Expand description
Outcome of merging managed entries into an existing settings/hooks
file. existing is the prior file content (None if the file did
not exist); rendered is the merged content the caller should
write.
Fields
existing: Option<String>rendered: StringTrait Implementations
Sourceimpl Clone for MergedFile
impl Clone for MergedFile
Sourcefn clone(&self) -> MergedFile
fn clone(&self) -> MergedFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MergedFile
impl Debug for MergedFile
Sourceimpl PartialEq for MergedFile
impl PartialEq for MergedFile
Sourcefn eq(&self, other: &MergedFile) -> bool
fn eq(&self, other: &MergedFile) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MergedFile
impl StructuralPartialEq for MergedFile