render_for

Function render_for 

pub fn render_for(
    adapter: SourceFileAdapter,
    integration_mode: IntegrationMode,
    client_slot: Option<&str>,
) -> RenderedSourceFile
Render the managed source file for adapter in integration_mode. client_slot is an opaque, optional client-supplied body. Lifeloop embeds it verbatim inside the managed section between <!-- CLIENT-SLOT:BEGIN --> and <!-- CLIENT-SLOT:END --> sub-markers. Lifeloop never parses or interprets the slot.