pub struct ManifestRenewalContinuation {
pub observation: SupportState,
pub payload_delivery: SupportState,
}Expand description
Continuation-side renewal capability. Observation means the adapter can prove a continuation boundary happened; payload delivery means it can carry client-provided continuation facts across that boundary.
Fields
observation: SupportStatepayload_delivery: SupportStateTrait Implementations
Sourceimpl Clone for ManifestRenewalContinuation
impl Clone for ManifestRenewalContinuation
Sourcefn clone(&self) -> ManifestRenewalContinuation
fn clone(&self) -> ManifestRenewalContinuation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManifestRenewalContinuation
impl Debug for ManifestRenewalContinuation
Sourceimpl<'de> Deserialize<'de> for ManifestRenewalContinuation
impl<'de> Deserialize<'de> for ManifestRenewalContinuation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ManifestRenewalContinuation
impl PartialEq for ManifestRenewalContinuation
Sourcefn eq(&self, other: &ManifestRenewalContinuation) -> bool
fn eq(&self, other: &ManifestRenewalContinuation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ManifestRenewalContinuation
impl StructuralPartialEq for ManifestRenewalContinuation