pub struct ManifestRenewalReset {
pub native: SupportState,
pub wrapper_mediated: SupportState,
pub manual: SupportState,
}Expand description
Reset-side renewal capability. native, wrapper_mediated, and
manual are separate so a manifest can distinguish a real harness
reset surface, a launcher/wrapper path, an operator-only path, and
the all-unavailable “no safe reset path” case.
Fields
native: SupportStatewrapper_mediated: SupportStatemanual: SupportStateTrait Implementations
Sourceimpl Clone for ManifestRenewalReset
impl Clone for ManifestRenewalReset
Sourcefn clone(&self) -> ManifestRenewalReset
fn clone(&self) -> ManifestRenewalReset
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManifestRenewalReset
impl Debug for ManifestRenewalReset
Sourceimpl<'de> Deserialize<'de> for ManifestRenewalReset
impl<'de> Deserialize<'de> for ManifestRenewalReset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ManifestRenewalReset
impl PartialEq for ManifestRenewalReset
Sourcefn eq(&self, other: &ManifestRenewalReset) -> bool
fn eq(&self, other: &ManifestRenewalReset) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ManifestRenewalReset
impl Serialize for ManifestRenewalReset
impl Eq for ManifestRenewalReset
impl StructuralPartialEq for ManifestRenewalReset