pub fn parse_session_log(
bytes: &[u8],
observed_at_epoch_s: u64,
) -> TelemetryResult<Option<PressureObservation>>Expand description
Parse a Codex session log byte slice. Public for tests and for callers that read the file themselves.
pub fn parse_session_log(
bytes: &[u8],
observed_at_epoch_s: u64,
) -> TelemetryResult<Option<PressureObservation>>Parse a Codex session log byte slice. Public for tests and for callers that read the file themselves.