current

Function current 

pub fn current() -> TelemetryResult<Option<PressureObservation>>
Probe the active Codex session log for the configured thread id. Returns Ok(None) when no thread id is configured or the session log has no token_count events yet.